# VariablesScopedToEnvironmentResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**has_unauthorized_project_variables** | **bool** |  | [optional] 
**has_unauthorized_library_variable_set_variables** | **bool** |  | [optional] 
**variable_map** | **dict(str, dict(str, int))** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


